==> svix-0.84.0.tar.gz: svix-0.84.0/svix/internal/openapi_client/api/endpoint/v1_endpoint_transformation_simulate.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import Client
from ...models.endpoint_transformation_simulate_in import EndpointTransformationSimulateIn
from ...models.endpoint_transformation_simulate_out import EndpointTransformationSimulateOut
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Unset


def _get_kwargs(
    app_id: str,
    endpoint_id: str,
    *,
    client: Client,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/endpoint/{endpoint_id}/transformation/simulate/".format(
        client.base_url, app_id=app_id, endpoint_id=endpoint_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if not isinstance(idempotency_key, Unset):
        headers["idempotency-key"] = idempotency_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> EndpointTransformationSimulateOut:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_200 = EndpointTransformationSimulateOut.from_dict(response.json())

    return response_200


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    endpoint_id: str,
    *,
    client: Client,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str):  Example: unique-app-identifier.
        endpoint_id (str):  Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    endpoint_id: str,
    *,
    client: Client,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str):  Example: unique-app-identifier.
        endpoint_id (str):  Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    return sync_detailed(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )


async def asyncio_detailed(
    app_id: str,
    endpoint_id: str,
    *,
    client: Client,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str):  Example: unique-app-identifier.
        endpoint_id (str):  Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    endpoint_id: str,
    *,
    client: Client,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str):  Example: unique-app-identifier.
        endpoint_id (str):  Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    return await asyncio_detailed(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

==> svix-0.84.1.tar.gz: svix-0.84.1/svix/internal/openapi_client/api/endpoint/v1_endpoint_transformation_simulate.py <==
import random
from time import sleep
from typing import Any, Dict, Union

import httpx

from ...client import AuthenticatedClient
from ...models.endpoint_transformation_simulate_in import EndpointTransformationSimulateIn
from ...models.endpoint_transformation_simulate_out import EndpointTransformationSimulateOut
from ...models.http_error import HttpError
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Unset


def _get_kwargs(
    app_id: str,
    endpoint_id: str,
    *,
    client: AuthenticatedClient,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> Dict[str, Any]:
    url = "{}/api/v1/app/{app_id}/endpoint/{endpoint_id}/transformation/simulate/".format(
        client.base_url, app_id=app_id, endpoint_id=endpoint_id
    )

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    if not isinstance(idempotency_key, Unset):
        headers["idempotency-key"] = idempotency_key

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> EndpointTransformationSimulateOut:
    if response.status_code == 401:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 403:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 404:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 409:
        raise HttpError(response.json(), response.status_code)
    if response.status_code == 422:
        raise HTTPValidationError(response.json(), response.status_code)
    if response.status_code == 429:
        raise HttpError(response.json(), response.status_code)
    response_200 = EndpointTransformationSimulateOut.from_dict(response.json())

    return response_200


sleep_time = 0.05
num_retries = 3


def sync_detailed(
    app_id: str,
    endpoint_id: str,
    *,
    client: AuthenticatedClient,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        endpoint_id (str): The ep's ID or UID Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    retry_count = 0
    for retry in range(num_retries):
        response = httpx.request(
            verify=client.verify_ssl,
            **kwargs,
        )
        if response.status_code >= 500 and retry < num_retries:
            retry_count += 1
            kwargs["headers"]["svix-retry-count"] = str(retry_count)
            sleep(sleep_time)
            sleep_time * 2
        else:
            break

    return _parse_response(response=response)


def sync(
    app_id: str,
    endpoint_id: str,
    *,
    client: AuthenticatedClient,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        endpoint_id (str): The ep's ID or UID Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    return sync_detailed(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )


async def asyncio_detailed(
    app_id: str,
    endpoint_id: str,
    *,
    client: AuthenticatedClient,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        endpoint_id (str): The ep's ID or UID Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    kwargs = _get_kwargs(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )

    kwargs["headers"] = {"svix-req-id": f"{random.getrandbits(32)}", **kwargs["headers"]}

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        retry_count = 0
        for retry in range(num_retries):
            response = await _client.request(**kwargs)
            if response.status_code >= 500 and retry < num_retries:
                retry_count += 1
                kwargs["headers"]["svix-retry-count"] = str(retry_count)
                sleep(sleep_time)
                sleep_time * 2
            else:
                break

    return _parse_response(response=response)


async def asyncio(
    app_id: str,
    endpoint_id: str,
    *,
    client: AuthenticatedClient,
    json_body: EndpointTransformationSimulateIn,
    idempotency_key: Union[Unset, str] = UNSET,
) -> EndpointTransformationSimulateOut:
    """Simulate

     Simulate running the transformation on the payload and code

    Args:
        app_id (str): The app's ID or UID Example: unique-app-identifier.
        endpoint_id (str): The ep's ID or UID Example: unique-ep-identifier.
        idempotency_key (Union[Unset, str]):
        json_body (EndpointTransformationSimulateIn):

    Returns:
        EndpointTransformationSimulateOut
    """

    return await asyncio_detailed(
        app_id=app_id,
        endpoint_id=endpoint_id,
        client=client,
        json_body=json_body,
        idempotency_key=idempotency_key,
    )
